==> haskell-persistent-postgresql-2.13.5.0-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.0
visibility:           public
id:                   persistent-postgresql-2.13.5.0-KKu3Fm0Kj0nCbb5V1BhLGq
key:                  persistent-postgresql-2.13.5.0-KKu3Fm0Kj0nCbb5V1BhLGq
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  874ecf7ebad02128cac4b06ffa9839df
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.0-KKu3Fm0Kj0nCbb5V1BhLGq
depends:
    aeson-2.1.2.1-30WJrKK1Pbc1pP0H7Lz8HG
    attoparsec-0.14.4-H7aeDSX4mnyDRaYndD48j5 base-4.17.2.1
    blaze-builder-0.4.4.1-GC1i0mzFnQi6MqAUVTXmHq bytestring-0.11.5.3
    conduit-1.3.6.1-L9TggbIlNiTCDF5rGZVa9g containers-0.6.7
    monad-logger-0.3.42-1b8laOi6Lo9Ff4ZKXfEEE7 mtl-2.2.2
    persistent-2.14.5.2-99DSNSe4dwBAfrxPWnpiEs
    postgresql-libpq-0.9.5.0-ISIgXFjP19REFuF01eqmjw
    postgresql-simple-0.6.5.1-I0WeAGyMMZhCkDQOk15HnT
    resource-pool-0.2.3.2-6l2qRlfIRMz587yYVY0pA6
    resourcet-1.2.6-FSCUiwlyZ0b8fgSbQ2cm0c
    string-conversions-0.4.0.1-At29VEfYfYXoXdSzJB7Sz text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vault-0.3.1.5-DnQp297eUTF7TPYlrAlANV

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-postgresql-2.13.5.0-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.0
visibility:           public
id:                   persistent-postgresql-2.13.5.0-Kyh82pb9XWb5tuf5dPtjRB
key:                  persistent-postgresql-2.13.5.0-Kyh82pb9XWb5tuf5dPtjRB
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  e4e49697580effbb99dd77c65829b508
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.5.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.0-Kyh82pb9XWb5tuf5dPtjRB
depends:
    aeson-2.1.2.1-4RB85zdNr5p3whZ1np3a31
    attoparsec-0.14.4-IvgQrznNozFJRhxLBW8JF base-4.17.2.1
    blaze-builder-0.4.4.1-BSmLbvNejToLEWeTg2SNQj bytestring-0.11.5.3
    conduit-1.3.6.1-8yY1jDXBMRk90iKvTAknJ8 containers-0.6.7
    monad-logger-0.3.42-Jxs0p57jAZ011tz8kZlBga mtl-2.2.2
    persistent-2.14.5.2-B2o3PxUxRuLAvIBekGkXkk
    postgresql-libpq-0.9.5.0-ISIgXFjP19REFuF01eqmjw
    postgresql-simple-0.6.5.1-76Diq2hlelL3FsWItl41Q4
    resource-pool-0.2.3.2-LP0aYoP1oLWF8R1f98nBpt
    resourcet-1.2.6-2WPOMAIVFIM62rtu43cRpf
    string-conversions-0.4.0.1-At29VEfYfYXoXdSzJB7Sz text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vault-0.3.1.5-R7HfyqchkWC0uGpaDAfNd

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
